<?php

/**
 * @file
 * Provides the administration settings for the Ping.fm web service.
 */

/**
 * Menu callback; Administration settings for Ping.fm.
 */
function pingfm_admin_settings() {
  $form['pingfm_dev_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Developer key'),
    '#description' => t('The global application key obtained !pingfm. This defaults to the Ping.fm Drupal application key, but you can use your own if you have one.', array('!pingfm' => l('Ping.fm', 'http://ping.fm/developers/'))),
    '#default_value' => variable_get('pingfm_dev_key', '4c625cb344fe57ba6167eb16036c7c35'),
    '#required' => TRUE,
  );
  $form['global_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Global settings'),
    '#collapsible' => TRUE,
  );
  $form['global_settings']['global_pingfm_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Global Ping.FM account key'),
    '#description' => t('If used this key will be the default account key that content will get posted to, unless the user posting the content has their own key in which their key will be used.'),
    '#default_value' => variable_get('global_pingfm_key', ''),
  );
  
  $form['node_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node settings'),
    '#description' => t('Settings related to pushing posts to Ping.fm when new nodes are created.'),
    '#collapsible' => TRUE,
  );
  $form['node_settings']['pingfm_nodetypes'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Node types'),
    '#description' => t('Allow Ping.fm updates from these node types.'),
    '#default_value' => variable_get('pingfm_nodetypes', array()),
    '#options' => node_get_types('names'),
  );
  $form['node_settings']['pingfm_default_format'] = array(
    '#type' => 'textfield',
    '#title' => t('Default format'),
    '#description' => t('The default format when posting to Ping.fm. Expand "Replacement patterns" to see more options.'),
    '#default_value' => variable_get('pingfm_default_format', '!url - !title: !teaser'),
  );
  $form['node_settings']['pingfm_replace'] = array(
    '#type' => 'fieldset',
    '#title' => t('Replacement patterns'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['node_settings']['pingfm_replace']['patterns'] = array(
    '#value' => pingfm_patterns_list(),
  );
  
  if (module_exists('shorten')) {
    $form['shorten_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Shorten Settings'),
      '#description' => t('Enable Shorten module integration.'),
      '#collapsed' => TRUE,
      '#collapsible' => TRUE,
    );
    $form['shorten_settings']['pingfm_shorten'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable'),
      '#default_value' => variable_get('pingfm_shorten', 0),
    );
  }
  
  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Advanced'),
  );
  $form['advanced']['pingfm_debug'] = array(
    '#type' => 'checkbox',
    '#title' => t('Debug'),
    '#description' => t('When enabled, tells Ping.fm that we are in debugging mode.'),
    '#default_value' => variable_get('pingfm_debug', FALSE),
  );
  return system_settings_form($form);
}

/**
 * Create a theme_table() with pattern values and descriptions as data.
 */
function pingfm_patterns_list() {
  $headers = array('Pattern', 'Description');
  $rows = array();
  
  $rows[] = array(t('!title'), t('Node title.'));
  $rows[] = array(t('!url'), t('Node URL.'));
  $rows[] = array(t('!teaser'), t('Node teaser.'));
  $rows[] = array(t('!user'), t('Node author.'));

  return theme_table($headers, $rows);
}
